@@ -7,14 +7,15 @@ test_that("uLSIF", {
 
   result <- uLSIF(x, y)
 
-  alpha <- result$alpha
+  kernel_weights <- result$kernel_weights
   sigma <- result$kernel_info$sigma
   lambda <- result$lambda
 
-  expected_alpha <- c(0.0674550859, 0.0400446153, 0.0004589047,
-                      0.0168489465, 0.0670843163, 0.0189929309)
+  expected_kernel_weights <- c(0.0674550859, 0.0400446153, 0.0004589047,
+                               0.0168489465, 0.0670843163, 0.0189929309)
 
-  expect_equal(head(alpha), expected_alpha)
+  testthat::skip_on_cran()
+  expect_equal(head(kernel_weights), expected_kernel_weights)
   expect_equal(sigma, 0.1)
   expect_equal(lambda, 1)
 })
